| Title: | Semi-Supervised Calibration of Risk with Noisy Event Times |
|---|---|
| Description: | A consistent, semi-supervised, non-parametric survival curve estimator optimized for efficient use of Electronic Health Record (EHR) data with a limited number of current status labels. See van der Laan and Robins (1997) <doi:10.2307/2670119>. |
| Authors: | Yuri Ahuja [aut, cre], PARSE Health [aut] |
| Maintainer: | Yuri Ahuja <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.2 |
| Built: | 2026-06-09 08:30:48 UTC |
| Source: | https://github.com/celehs/scornet |
Semi-Supervised Calibration of Risk with Noisy Event Times (SCORNET) is a consistent, non-parametric survival curve estimator that boosts efficiency over existing non-parametric estimators by (1) utilizing unlabeled patients in a semi-supervised fashion, and (2) leveraging information-dense engineered EHR features to maximize unlabeled set imputation precision See Ahuja et al. (2020) BioArxiv for details
Maintainer: Yuri Ahuja [email protected]
Authors:
PARSE Health
Useful links:
SCORNET Estimator
scornet( Delta, C, t0.all, C.UL = NULL, filter = NULL, filter.UL = NULL, Z0 = NULL, Z0.UL = NULL, Zehr = NULL, Zehr.UL = NULL, K = Knorm, b = NULL, bexp = -1/4, fc = NULL, nCores = 1 )scornet( Delta, C, t0.all, C.UL = NULL, filter = NULL, filter.UL = NULL, Z0 = NULL, Z0.UL = NULL, Zehr = NULL, Zehr.UL = NULL, K = Knorm, b = NULL, bexp = -1/4, fc = NULL, nCores = 1 )
Delta |
Labeled set current status labels (I(T<C)) |
C |
Labeled set censoring times |
t0.all |
Times at which to estimate survival |
C.UL |
Unlabeled set censoring times |
filter |
Labeled set binary filter indicators |
filter.UL |
Unlabeled set filter indicators |
Z0 |
Labeled set baseline feature matrix |
Z0.UL |
Unlabeled set baseline feature matrix |
Zehr |
Labeled set EHR-derived feature matrix |
Zehr.UL |
Unlabeled set EHR-derived feature matrix |
K |
Kernel function (defaults to standard normal) |
b |
bandwidth (optional) |
bexp |
bandwidth exponent (must be between -1/5 and -1/3, defaults to -1/4) |
fc |
N^1/4-consistent pdf estimator of C|Z0 (defaults to Kernel-Smoothed Cox/Breslow estimator) |
nCores |
Number of cores to use for parallelization (defaults to 1) |
S_hat: Survival function estimates at times t0.all; StdErrs: Asymptotically consistent standard error estimates corresponding to S_hat